@@ -26,6 +26,7 @@ class HapiJpaStarterParams(object):
         self.git_url: t.Optional[str] = None
         self.git_ref: t.Optional[str] = None
         self.hapi_port: t.Optional[int] = None
+        self.fhir_address: t.Optional[str] = None
         self.mvn_local_repo: t.Optional[str] = None
         self.mvn_rebuild: t.Optional[bool] = False
         self.dbs_work_dir: t.Optional[str] = None
@@ -54,6 +55,7 @@ class HapiJpaStarterState(FhirServerState):
 @click.option('--git-url', default='https://github.com/hapifhir/hapi-fhir-jpaserver-starter.git')
 @click.option('--git-ref', default='master')
 @click.option('--hapi-port', type=int, default=8888)
+@click.option('--fhir-address', default='http://localhost:{}/fhir')
 @click.option('--mvn-local-repo', default='.m2')
 @click.option('--mvn-rebuild', is_flag=True)
 @click.option('--dbs-work-dir')
@@ -71,6 +73,7 @@ def command(
         git_url,
         git_ref,
         hapi_port,
+        fhir_address,
         mvn_local_repo,
         mvn_rebuild,
         dbs_work_dir,
@@ -91,6 +94,7 @@ def command(
     params.git_url = git_url
     params.git_ref = git_ref
     params.hapi_port = hapi_port
+    params.fhir_address = fhir_address
     params.mvn_local_repo = mvn_local_repo
     params.mvn_rebuild = mvn_rebuild
     params.dbs_work_dir = dbs_work_dir
@@ -167,34 +171,6 @@ class HapiJpaStarterAction(Action[HapiJpaStarterState]):
             if self.state.status == 'running':
                 return
 
-        with open(self.hapi_run_path / 'application-local.yaml') as f:
-            hapi_local_config = yaml.safe_load(f)
-        if hapi_local_config is None:
-            hapi_local_config = {}
-
-        if 'server' not in hapi_local_config:
-            hapi_local_config['server'] = {}
-
-        port = setupservers.find_free_port('localhost', self.state.params.hapi_port)
-
-        hapi_local_config['server']['port'] = port
-
-        if 'hapi' not in hapi_local_config:
-            hapi_local_config['hapi'] = {}
-        if 'fhir' not in hapi_local_config['hapi']:
-            hapi_local_config['hapi']['fhir'] = {}
-
-        if 'tester' not in hapi_local_config['hapi']['fhir']:
-            hapi_local_config['hapi']['fhir']['tester'] = {}
-        if 'home' not in hapi_local_config['hapi']['fhir']['tester']:
-            hapi_local_config['hapi']['fhir']['tester']['home'] = {}
-
-        self.state.fhir_url = f'http://localhost:{port}/fhir'
-        hapi_local_config['hapi']['fhir']['tester']['home']['server_address'] = self.state.fhir_url
-
-        with open(self.hapi_run_path / 'application-local.yaml', 'w') as f:
-            yaml.safe_dump(hapi_local_config, f)
-
         args = ['java',
                 f'-Dspring.profiles.active={self.state.params.spring_profiles}',
                 f'-Dlogging.config={str(self.hapi_run_path / "logback.xml")}'
@@ -225,9 +201,47 @@ class HapiJpaStarterAction(Action[HapiJpaStarterState]):
         p = subprocess.Popen(args, cwd=self.hapi_run_path)
         self.state.pid = p.pid
         self.state.status = 'running'
+        self._hapi_config()
         self.state.save()
         self.logger.info(f"HAPI FHIR endpoint starting on: {self.state.fhir_url}")
 
+    def _hapi_config(self):
+
+        with open(self.hapi_run_path / 'application-local.yaml') as f:
+            hapi_local_config = yaml.safe_load(f)
+        if hapi_local_config is None:
+            hapi_local_config = {}
+
+        if 'server' not in hapi_local_config:
+            hapi_local_config['server'] = {}
+
+        if 'address' not in hapi_local_config['server']:
+            hapi_local_config['server']['address'] = '0.0.0.0'
+
+        port = setupservers.find_free_port(hapi_local_config['server']['address'], self.state.params.hapi_port)
+        self.state.fhir_url = self.state.params.fhir_address.format(port)
+
+        hapi_local_config['server']['port'] = port
+
+        if 'hapi' not in hapi_local_config:
+            hapi_local_config['hapi'] = {}
+
+        if 'fhir' not in hapi_local_config['hapi']:
+            hapi_local_config['hapi']['fhir'] = {}
+
+        hapi_local_config['hapi']['fhir']['server_address'] = self.state.fhir_url
+
+        if 'tester' not in hapi_local_config['hapi']['fhir']:
+            hapi_local_config['hapi']['fhir']['tester'] = {}
+
+        if 'home' not in hapi_local_config['hapi']['fhir']['tester']:
+            hapi_local_config['hapi']['fhir']['tester']['home'] = {}
+
+        hapi_local_config['hapi']['fhir']['tester']['home']['server_address'] = self.state.fhir_url
+
+        with open(self.hapi_run_path / 'application-local.yaml', 'w') as f:
+            yaml.safe_dump(hapi_local_config, f)
+
     def _hapi_stop(self):
         if self.state.pid is None:
             self.logger.info("HAPI already stopped.")
